@@ -26,8 +26,8 @@ public interface DeployedAssembly {
 
     String getName();
 
-    void deploy();
-
     Map<String, String> getServiceUnits();
 
+    void undeploy(boolean restart);
+
 }
