@@ -18,6 +18,7 @@ package org.apache.servicemix.nmr.core;
 
 import org.apache.camel.impl.converter.DefaultTypeConverter;
 import org.apache.camel.util.ReflectionInjector;
+import org.apache.camel.NoTypeConversionAvailableException;
 
 /**
  * A converter using Camel underneath
@@ -27,7 +28,11 @@ class CamelConverter implements Converter {
     final DefaultTypeConverter tc = new DefaultTypeConverter(new ReflectionInjector());
 
     public <T> T convert(Object body, Class<T> type) {
-        return tc.convertTo(type, body);
+        try {
+            return tc.convertTo(type, body);
+        } catch (NoTypeConversionAvailableException e) {
+            return null;
+        }
     }
 
 }
